@@ -27,19 +27,12 @@
 #
 #
 
-__author__ = "Dominic Davis-Foster"
-__copyright__ = "Copyright 2014-2019 Dominic Davis-Foster"
-
-__license__ = "GPL"
-__version__ = "0.1.0"
-__email__ = "dominic@davis-foster.co.uk"
-
 import os
 import shlex
 import struct
 import platform
 import subprocess
-from . import pyversion
+from .__init__ import pyversion
 
 
 def clear():  # clear the display
